==> stylish-haskell-0.9.2.1-47-x86_64.pkg.tar.xz: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stylish-haskell
version: 0.9.2.1
id: stylish-haskell-0.9.2.1-GFwOpw58hQB9rVtIEs35HM
key: stylish-haskell-0.9.2.1-GFwOpw58hQB9rVtIEs35HM
license: BSD-3-Clause
copyright: 2012 Jasper Van der Jeugt
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: https://github.com/jaspervdj/stylish-haskell
synopsis: Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:
    .
    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>
category: Language
abi: 01efcefee2c182fe725ae4f7cfd4c575
exposed: True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax
hidden-modules: Language.Haskell.Stylish.Align
                Language.Haskell.Stylish.Block Language.Haskell.Stylish.Config
                Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Parse
                Language.Haskell.Stylish.Step Language.Haskell.Stylish.Util
                Language.Haskell.Stylish.Verbose Paths_stylish_haskell
import-dirs: /usr/lib/ghc-8.6.5/site-local/stylish-haskell-0.9.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/stylish-haskell-0.9.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/stylish-haskell
hs-libraries: HSstylish-haskell-0.9.2.1-GFwOpw58hQB9rVtIEs35HM
depends:
    aeson-1.4.4.0-KIBRt7ojt2h8yml6gHrkIF base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    haskell-src-exts-1.21.0-JABLkjBtye0ArRObtnXach mtl-2.2.2
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    yaml-0.11.1.0-67VYy3qd4XOJJ9QFlTkB8C
haddock-interfaces: /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html: /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.9.2.1-50-x86_64.pkg.tar.xz: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stylish-haskell
version: 0.9.2.1
id: stylish-haskell-0.9.2.1-4SUNQHLndMR5cRF2oYw6mm
key: stylish-haskell-0.9.2.1-4SUNQHLndMR5cRF2oYw6mm
license: BSD-3-Clause
copyright: 2012 Jasper Van der Jeugt
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: https://github.com/jaspervdj/stylish-haskell
synopsis: Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:
    .
    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>
category: Language
abi: 68bc1dcd1633a8af02cc04b4f1862d28
exposed: True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax
hidden-modules: Language.Haskell.Stylish.Align
                Language.Haskell.Stylish.Block Language.Haskell.Stylish.Config
                Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Parse
                Language.Haskell.Stylish.Step Language.Haskell.Stylish.Util
                Language.Haskell.Stylish.Verbose Paths_stylish_haskell
import-dirs: /usr/lib/ghc-8.6.5/site-local/stylish-haskell-0.9.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/stylish-haskell-0.9.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/stylish-haskell
hs-libraries: HSstylish-haskell-0.9.2.1-4SUNQHLndMR5cRF2oYw6mm
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    haskell-src-exts-1.21.0-1f3RZCx0YCMHHsp4hwgt6k mtl-2.2.2
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    yaml-0.11.1.0-8jFA6LZR6hejvB1XYns97
haddock-interfaces: /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html: /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
